Quick How to Example On REST API
--------------------------------

Simple contacts application.

Insert test data::

    $ python testdata.py

Run it::

    $ flask fab create-admin
    $ flask run

For Swagger view go to: http://localhost:5000/swagger/v1
